Issie logo Issie

JoinEnd Type

One end of a channel: a join component, in one copy, on the channel that copy puts it on.

Record fields

Record Field Description

Comp

Full Usage: Comp

Field type: Component

The join component as drawn on the array sheet.

Field type: Component

Copy

Full Usage: Copy

Field type: int

Which copy this end belongs to, 0 .. copies-1.

Field type: int

Num

Full Usage: Num

Field type: int

The channel it is on in that copy - its number expression evaluated with the loop variable set to Copy.

Field type: int

Type something to start searching.