Issie logo Issie

ExportResult Type

What exporting a library did: how many components were written, and how many were removed from the destination because this library no longer has them.

Record fields

Record Field Description

Destination

Full Usage: Destination

Field type: string
Field type: string

Removed

Full Usage: Removed

Field type: int
Field type: int

Written

Full Usage: Written

Field type: int
Field type: int

Type something to start searching.