Header menu logo issie

OpenedLibrary Type

What opening a library found: the components it can offer, and anything that would not read. A file that will not read costs that component, never the library.

Record fields

Record Field Description

Components

Full Usage: Components

Field type: LibraryListing list
Field type: LibraryListing list

Name

Full Usage: Name

Field type: string
Field type: string

Path

Full Usage: Path

Field type: string
Field type: string

Problems

Full Usage: Problems

Field type: string list
Field type: string list

Type something to start searching.