DirectedPortId Type
Wraps around the input and output port id types A port named together with the side of a connection it is: the undirected id is PortId, which this carries inside InputPortId or OutputPortId.
Union cases
| Union case | Description |
|
|
|
|
Instance members
| Instance member | Description |
Full Usage:
this.IsInputId
Returns: bool
|
|
Full Usage:
this.IsOutputId
Returns: bool
|
|