Issie logo Issie

PortMaps Type

data structures defining where ports are put on symbol boundary, by PortId - which is an integer wrapper, not the string it was when this was written

Record fields

Record Field Description

Order

Full Usage: Order

Field type: Map<Edge, PortId list>

Maps edge to list of ports on that edge, in correct order

Field type: Map<Edge, PortId list>

Orientation

Full Usage: Orientation

Field type: Map<PortId, Edge>

Maps the port ids to which side of the component the port is on

Field type: Map<PortId, Edge>

Type something to start searching.