Header menu logo issie

SimpleJson Module

Functions and values

Function or value Description

fromObjectLiteral x

Full Usage: fromObjectLiteral x

Parameters:
    x : 'a

Returns: Json option

Tries to convert an object literal to the Json by calling JSON.stringify on the object first

x : 'a
Returns: Json option

mapKeys f _arg1

Full Usage: mapKeys f _arg1

Parameters:
    f : string -> string
    _arg1 : Json

Returns: Json

Transforms all keys of the objects within the Json structure

f : string -> string
_arg1 : Json
Returns: Json

mapKeysByPath f json

Full Usage: mapKeysByPath f json

Parameters:
    f : string list -> string option
    json : Json

Returns: Json

Transforms keys of object selectively by path segments

f : string list -> string option
json : Json
Returns: Json

mapbyKey f _arg1

Full Usage: mapbyKey f _arg1

Parameters:
Returns: Json

Transforms object values recursively using function `f` that takes the key and value of the object and returns a new value

f : string -> Json -> Json
_arg1 : Json
Returns: Json

parse input

Full Usage: parse input

Parameters:
    input : string

Returns: Json

Parses the input string into a structured JSON data. Fails with an exception if parsing fails.

input : string
Returns: Json

parseNative input

Full Usage: parseNative input

Parameters:
    input : string

Returns: Json

Parses and converts the input string to Json using Javascript's native parsing capabilities

input : string
Returns: Json

readPath keys input

Full Usage: readPath keys input

Parameters:
    keys : string list
    input : Json

Returns: Json option
keys : string list
input : Json
Returns: Json option

stringify value

Full Usage: stringify value

Parameters:
    value : 'a

Returns: string
value : 'a
Returns: string

toPlainObject input

Full Usage: toPlainObject input

Parameters:
Returns: obj
input : Json
Returns: obj

toString _arg1

Full Usage: toString _arg1

Parameters:
Returns: string

Stringifies a Json object back to string representation

_arg1 : Json
Returns: string

tryParse input

Full Usage: tryParse input

Parameters:
    input : string

Returns: Option<Json>

Tries to parse a string into a Json structured JSON data.

input : string
Returns: Option<Json>

tryParseNative input

Full Usage: tryParseNative input

Parameters:
    input : string

Returns: Json option
input : string
Returns: Json option

Type something to start searching.