EvalReference Module
Functions and values
| Function or value | Description |
Full Usage:
fastReduce step isClockedReduction comp
Parameters:
StepIndex
isClockedReduction : bool
comp : FastComponent
Returns: Unit
|
Given a component, compute its outputs from its inputs, which must already be evaluated. Outputs and inputs are both contained as time sequences in arrays. This function will calculate simStep outputs from (previously calculated) simStep outputs and clocked (simStep-1) outputs. Memory has state separate from simStep-1 output, for this the state is recalculated. Inputs and outputs come from either the UInt32 or BigInt slab region of the IOArray record.
|
Full Usage:
fastReduceStep maxArraySize numStep isClockedReduction comp
Parameters:
int
numStep : int
isClockedReduction : bool
comp : FastComponent
Returns: Unit
|