Header menu logo issie

FastOrder Module

Functions and values

Function or value Description

canBeReduced fs step fc

Full Usage: canBeReduced fs step fc

Parameters:
Returns: bool
Modifiers: inline

True if all conditions are fulfiled for the component to be in the next batch to be reduced. Used when ordering components.

fs : FastSimulation
step : int
fc : FastComponent
Returns: bool

isComb comp

Full Usage: isComb comp

Parameters:
Returns: bool
Modifiers: inline

True if the component is combinational

comp : FastComponent
Returns: bool

orderCombinationalComponents numSteps fs

Full Usage: orderCombinationalComponents numSteps fs

Parameters:
Returns: FastSimulation

Create arrays of components in corrected format for efficient reduction Combinational components are ordered: clokced, constant, global input components are separated.

numSteps : int
fs : FastSimulation
Returns: FastSimulation

orderCombinationalComponentsFData numSteps fs

Full Usage: orderCombinationalComponentsFData numSteps fs

Parameters:
Returns: FastSimulation
numSteps : int
fs : FastSimulation
Returns: FastSimulation

printComp fs step fc

Full Usage: printComp fs step fc

Parameters:
Returns: string

print function for debugging

fs : FastSimulation
step : int
fc : FastComponent
Returns: string

Type something to start searching.