Header menu logo issie

WaveSimRams Module

RAM display in waveform simulator

Functions and values

Function or value Description

ramTable dispatch wsModel model (arg4, arg5)

Full Usage: ramTable dispatch wsModel model (arg4, arg5)

Parameters:
Returns: ReactElement

Table showing contents of a RAM component.

dispatch : Msg -> unit
wsModel : WaveSimModel
model : Model
arg3 : FComponentId
arg4 : string
Returns: ReactElement

ramTableRow hasComments (arg2, arg3, arg4, arg5)

Full Usage: ramTableRow hasComments (arg2, arg3, arg4, arg5)

Parameters:
    hasComments : bool
    arg1 : string
    arg2 : string
    arg3 : string
    arg4 : RamRowType

Returns: ReactElement

Table row that shows the address and data of a RAM component, and what the .ram file it was initialised from had to say about that location. The comment column is there only when the memory has comments, so that every row of a table has the same cells.

hasComments : bool
arg1 : string
arg2 : string
arg3 : string
arg4 : RamRowType
Returns: ReactElement

ramTables dispatch wsModel model

Full Usage: ramTables dispatch wsModel model

Parameters:
Returns: ReactElement

Bulma Level component of tables showing RAM contents.

dispatch : Msg -> unit
wsModel : WaveSimModel
model : Model
Returns: ReactElement

Type something to start searching.