ResultList Module
Running a list of operations that can fail, stopping at the first Error. Written out by hand this is a fold over Result whose accumulator is built with `got @ [x]`, which is quadratic and was repeated in half a dozen places. These are linear and are the only version.
Functions and values
| Function or value | Description |
|
|
|
|
|
|
|