Header menu logo issie

ConnectionId Type

Unique integer id of a connection, unique within its SHEET only - nothing resolves a connection id outside the sheet it belongs to (error highlighting is sheet-guarded).

Union cases

Union case Description

ConnectionId int

Full Usage: ConnectionId int

Parameters:
    Item : int

Item : int

Type something to start searching.