Header menu logo issie

PortId Type

The id of a port, undirected: see InputPortId and OutputPortId below for the directed forms the code uses where it knows which side of a connection it is on.

Union cases

Union case Description

PortId int

Full Usage: PortId int

Parameters:
    Item : int

Item : int

Type something to start searching.