FetchSnapshot Type
What one fetch was for - recorded on its completion as what WAS fetched, never what is current by then. Each part is Some only when that viewport differed when the fetch was issued.
Record fields
| Record Field | Description |
|
|
|
|
What one fetch was for - recorded on its completion as what WAS fetched, never what is current by then. Each part is Some only when that viewport differed when the fetch was issued.
| Record Field | Description |
|
|
|
|