Issie logo Issie

SidecarAnswer Type

What an operation answered. One case per operation, so that an answer cannot be handled as though it were the answer to something else.

Union cases

Union case Description

AnsBuilt Result<int, SidecarFailure>

Full Usage: AnsBuilt Result<int, SidecarFailure>

Parameters:
Item : Result<int, SidecarFailure>

AnsFetched(Result<unit, SidecarFailure>, (FComponentId * (RamKey * RamView)) list, (WaveIndexT * int * bigint) option)

Full Usage: AnsFetched(Result<unit, SidecarFailure>, (FComponentId * (RamKey * RamView)) list, (WaveIndexT * int * bigint) option)

Parameters:
Item1 : Result<unit, SidecarFailure>
Item2 : (FComponentId * (RamKey * RamView)) list
Item3 : (WaveIndexT * int * bigint) option

AnsRan Result<(int * bool), SidecarFailure>

Full Usage: AnsRan Result<(int * bool), SidecarFailure>

Parameters:

the clock the chunk reached, and whether it reached the cycle asked for

Item : Result<(int * bool), SidecarFailure>

AnsStepped

Full Usage: AnsStepped

AnsSteppedTo(before, startedMs, result)

Full Usage: AnsSteppedTo(before, startedMs, result)

Parameters:

One chunk of a step-simulation run completed: where the clock was when the chunk was asked for, when it was asked (ms on the performance clock, for the speed display), and where the SIMULATOR says it now is - the fact the model's clock is set to, never incremented towards.

before : int
startedMs : float
result : Result<(int * bool), SidecarFailure>

Instance members

Instance member Description

this.IsAnsBuilt

Full Usage: this.IsAnsBuilt

Returns: bool
Returns: bool

this.IsAnsFetched

Full Usage: this.IsAnsFetched

Returns: bool
Returns: bool

this.IsAnsRan

Full Usage: this.IsAnsRan

Returns: bool
Returns: bool

this.IsAnsStepped

Full Usage: this.IsAnsStepped

Returns: bool
Returns: bool

this.IsAnsSteppedTo

Full Usage: this.IsAnsSteppedTo

Returns: bool
Returns: bool

Type something to start searching.