Header menu logo issie

Constants Module

Functions and values

Function or value Description

maxBinaryDisplayWidth

Full Usage: maxBinaryDisplayWidth

Returns: int

width at which binary numbers are displayed as (more compact) hex numbers.

Returns: int

maxHexOnlyDisplayWidth

Full Usage: maxHexOnlyDisplayWidth

Returns: int

width at which numbers that display as very small signe ddecimal numbers are so displayed

Returns: int

maxIssieBusWidth

Full Usage: maxIssieBusWidth

Returns: int

Max width of an Issie bus. Defined in CommonTypes.Constants, which is compiled early enough for ComponentSlots.constraintsFor to bound a width slot with it; aliased here because this is where the rest of Issie looks for it.

Returns: int

maxNumericCharsBeforeTruncation

Full Usage: maxNumericCharsBeforeTruncation

Returns: int

max no of chars displayed before display functions truncate result

Returns: int

Type something to start searching.