ParamSlot Type
A slot in a component instance that can be bound to a parameter expression. ComponentId 0 is the sentinel for "no component" - a popup's dialog box.
Record fields
| Record Field | Description |
|
|
|
|
A slot in a component instance that can be bound to a parameter expression. ComponentId 0 is the sentinel for "no component" - a popup's dialog box.
| Record Field | Description |
|
|
|
|