ComponentSlots Type
Every port of one component of one instance, positionally: array index = port number, which is the design's own numbering (a Component's port lists are position-numbered).
Record fields
| Record Field | Description |
|
|
|
|
|
Every port of one component of one instance, positionally: array index = port number, which is the design's own numbering (a Component's port lists are position-numbered).
| Record Field | Description |
|
|
|
|
|