Issie logo Issie

RamView Type

Which of the two displays a table is showing, and its rows.

Union cases

Union case Description

RamSparse RamRow list

Full Usage: RamSparse RamRow list

Parameters:

every location that is non-zero at this clock, in address order - there were few enough to list, so a gap between two of them means every location in it is zero

Item : RamRow list

RamWindow(start, rows)

Full Usage: RamWindow(start, rows)

Parameters:
    start : bigint
    rows : RamRow list

a window of consecutive locations from `Start`, zeros included, because there were too many to list

start : bigint
rows : RamRow list

Instance members

Instance member Description

this.IsRamSparse

Full Usage: this.IsRamSparse

Returns: bool
Returns: bool

this.IsRamWindow

Full Usage: this.IsRamWindow

Returns: bool
Returns: bool

Type something to start searching.