Issie logo Issie

Constants Module

Functions and values

Function or value Description

maxArraySize

Full Usage: maxArraySize

Returns: int

the step-array size every digest simulation is built with, so array wrap behaviour is identical everywhere the digest is computed (and identical to the golden tests)

Returns: int

Type something to start searching.