Header menu logo issie

FastData Type

Record fields

Record Field Description

Dat

Full Usage: Dat

Field type: FastBits
Field type: FastBits

Width

Full Usage: Width

Field type: int
Field type: int

Instance members

Instance member Description

this.GetBigInt

Full Usage: this.GetBigInt

Returns: bigint
Modifiers: inline
Returns: bigint

this.GetQUint32

Full Usage: this.GetQUint32

Returns: uint32
Modifiers: inline

can fail - for fast access to word data

Returns: uint32

this.GetUint32

Full Usage: this.GetUint32

Returns: uint32 option
Modifiers: inline

return Some uint32 representing data if possible else None

Returns: uint32 option

Static members

Static member Description

FastData.MakeFastData(width) (data)

Full Usage: FastData.MakeFastData(width) (data)

Parameters:
    width : int
    data : bigint

Returns: FastData
Modifiers: inline

if given width <= 32 it will generate Word form FastData, otherwise BigWord. The value is masked into the width, since every stored value must be within its bus width. NB this used to store a positive unmasked (MakeFastData 2 4I gave 4) and to reduce a negative with %, which leaves a negative remainder rather than the two's complement pattern.

width : int
data : bigint
Returns: FastData

Type something to start searching.