Issie logo Issie

Transition Type

create a new array which samples the old one every mult cycles. start: index of first cycle. count: number of samples. Determines whether a clock cycle is generated with a vertical bar at the beginning, denoting that a waveform changes value at the start of that clock cycle. NB this does not determine whether a waveform changes value at the end of that clock cycle. TODO: Remove this since it is unnecessary. Can use WaveValues instead. Determines whether a non-binary waveform changes value at the beginning of that clock cycle. Waveforms can be either binary or non-binary; these have different properties.

Union cases

Union case Description

BinaryTransition BinaryTransition

Full Usage: BinaryTransition BinaryTransition

Parameters:
Item : BinaryTransition

NonBinaryTransition NonBinaryTransition

Full Usage: NonBinaryTransition NonBinaryTransition

Parameters:
Item : NonBinaryTransition

Instance members

Instance member Description

this.IsBinaryTransition

Full Usage: this.IsBinaryTransition

Returns: bool
Returns: bool

this.IsNonBinaryTransition

Full Usage: this.IsNonBinaryTransition

Returns: bool
Returns: bool

Type something to start searching.