Issie logo Issie

BinaryTransition Type

Whether a binary waveform changes at the start of a clock cycle, and what it changes between.

Union cases

Union case Description

OneToOne

Full Usage: OneToOne

OneToZero

Full Usage: OneToZero

ZeroToOne

Full Usage: ZeroToOne

ZeroToZero

Full Usage: ZeroToZero

Instance members

Instance member Description

this.IsOneToOne

Full Usage: this.IsOneToOne

Returns: bool
Returns: bool

this.IsOneToZero

Full Usage: this.IsOneToZero

Returns: bool
Returns: bool

this.IsZeroToOne

Full Usage: this.IsZeroToOne

Returns: bool
Returns: bool

this.IsZeroToZero

Full Usage: this.IsZeroToZero

Returns: bool
Returns: bool

Type something to start searching.