OutlinePort Type
One port of an array component's outline: what it is called, how wide it is, which drawn component it comes from, and what the array does with it.
One port of an array component's outline: what it is called, how wide it is, which drawn component it comes from, and what the array does with it.