Signature Type
A sheet's ports: input labels and widths, then output labels and widths, each in the order the components appear on the sheet.
Instance members
| Instance member | Description |
Full Usage:
this.Item1
Returns: (string * int) list
|
|
Full Usage:
this.Item2
Returns: (string * int) list
|
|