ExportResult Type
What exporting a library did: how many components were written, and how many were removed from the destination because this library no longer has them.
Record fields
| Record Field | Description |
Full Usage:
Destination
Field type: string
|
|
Full Usage:
Removed
Field type: int
|
|
Full Usage:
Written
Field type: int
|
|