OpenedLibrary Type
What opening a library found: the components it can offer, and anything that would not read. A file that will not read costs that component, never the library.
Record fields
| Record Field | Description |
|
|
Full Usage:
Name
Field type: string
|
|
Full Usage:
Path
Field type: string
|
|
Full Usage:
Problems
Field type: string list
|
|