Header menu logo issie

Convert Module

Types

Type Description

InternalMap

Functions and values

Function or value Description

arrayLike _arg1

Full Usage: arrayLike _arg1

Parameters:
Returns: bool

Returns whether the type information resembles a type of a sequence of elements (including tuples)

_arg1 : TypeInfo
Returns: bool

betweenQuotes input

Full Usage: betweenQuotes input

Parameters:
    input : string

Returns: string
input : string
Returns: string

flatteFable3Map tree

Full Usage: flatteFable3Map tree

Parameters:
Returns: (string * Json) list
tree : Map<string, Json>
Returns: (string * Json) list

flattenFable3Lists linkedList

Full Usage: flattenFable3Lists linkedList

Parameters:
Returns: Json list
linkedList : Map<string, Json>
Returns: Json list

flattenMap _arg1

Full Usage: flattenMap _arg1

Parameters:
Returns: (string * Json) list
_arg1 : InternalMap
Returns: (string * Json) list

fromJson json typeInfo

Full Usage: fromJson json typeInfo

Parameters:
Returns: 't
json : Json
typeInfo : TypeInfo
Returns: 't

fromJsonAs input typeInfo

Full Usage: fromJsonAs input typeInfo

Parameters:
Returns: obj
input : Json
typeInfo : TypeInfo
Returns: obj

generateMap json

Full Usage: generateMap json

Parameters:
Returns: InternalMap option
json : Json
Returns: InternalMap option

insideBrowser

Full Usage: insideBrowser

Returns: bool
Returns: bool

isQuoted input

Full Usage: isQuoted input

Parameters:
    input : string

Returns: bool
input : string
Returns: bool

isRecord _arg1

Full Usage: isRecord _arg1

Parameters:
Returns: bool
_arg1 : TypeInfo
Returns: bool

isUsingFable3

Full Usage: isUsingFable3

Returns: bool
Returns: bool

optional _arg1

Full Usage: optional _arg1

Parameters:
Returns: bool
_arg1 : TypeInfo
Returns: bool

quoteText inputText

Full Usage: quoteText inputText

Parameters:
    inputText : string

Returns: string
inputText : string
Returns: string

removeQuotes input

Full Usage: removeQuotes input

Parameters:
    input : string

Returns: string
input : string
Returns: string

serialize value typeInfo

Full Usage: serialize value typeInfo

Parameters:
Returns: string
value : objnull
typeInfo : TypeInfo
Returns: string

unionOfRecords _arg1

Full Usage: unionOfRecords _arg1

Parameters:
Returns: bool
_arg1 : TypeInfo
Returns: bool

usingFable3 ()

Full Usage: usingFable3 ()

Parameters:
    () : unit

Returns: bool

Uses internal representation of F# maps to determine whether we are using Fable 3 or not

() : unit
Returns: bool

Active patterns

Active pattern Description

(|KeyValue|_|) key map

Full Usage: (|KeyValue|_|) key map

Parameters:
    key : string
    map : Map<string, Json>

Returns: (string * Json * Map<string, Json>) option
key : string
map : Map<string, Json>
Returns: (string * Json * Map<string, Json>) option

(|MapEmpty|_|) json

Full Usage: (|MapEmpty|_|) json

Parameters:
Returns: Json option
json : Json
Returns: Json option

(|MapKey|_|) _arg1

Full Usage: (|MapKey|_|) _arg1

Parameters:
Returns: string option
_arg1 : Json
Returns: string option

(|MapNode|_|) _arg1

Full Usage: (|MapNode|_|) _arg1

Parameters:
Returns: (string * Json * Json * Json) option
_arg1 : Json
Returns: (string * Json * Json * Json) option

(|MapOne|_|) _arg1

Full Usage: (|MapOne|_|) _arg1

Parameters:
Returns: (string * Json) option
_arg1 : Json
Returns: (string * Json) option

(|NonArray|_|) _arg1

Full Usage: (|NonArray|_|) _arg1

Parameters:
Returns: Json option
_arg1 : Json
Returns: Json option

Type something to start searching.