Header menu logo issie

FastRun Module

Nested modules

Modules Description

Constants

Functions and values

Function or value Description

runCombinationalLogic stepNum fastSim

Full Usage: runCombinationalLogic stepNum fastSim

Parameters:

Re-evaluates the combinational logic for the given timestep - used if a combinational input has changed

stepNum : int
fastSim : FastSimulation

runCombinationalLogicFData step fastSim

Full Usage: runCombinationalLogicFData step fastSim

Parameters:
step : int
fastSim : FastSimulation

runFastSimulation timeOut lastStepNeeded fs

Full Usage: runFastSimulation timeOut lastStepNeeded fs

Parameters:
Returns: float option

Run an existing fast simulation up to the given number of steps. This function will mutate the write-once data arrays of simulation data and only simulate the new steps needed, so it may return immediately doing no work. If the simulation data arrays are not large enough they are extended up to a limit. After that, they act as a circular buffer. TimeOut if not None is the cutoff time after which the simulation terminates execution unfinished. Use fs.ClockTick to determine whether simulation has completed. returns speed, in clock cycles per ms, or None if complete

timeOut : float option
lastStepNeeded : int
fs : FastSimulation
Returns: float option

Type something to start searching.