WaveSimSVGs Module
Functions to make SVGs of waveforms from FastSimulation data
Types and nested modules
Functions and values
| Function or value | Description |
Full Usage:
binaryWavePoints clkCycleWidth startCycle index transition
Parameters:
float
startCycle : int
index : int
transition : BinaryTransition
Returns: XYPos array
|
|
Full Usage:
calculateBinaryTransitionsUInt32 waveValues startCycle shownCycles multiplier
Parameters:
uint32 array
startCycle : int
shownCycles : int
multiplier : int
Returns: BinaryTransition array
|
|
Full Usage:
calculateNonBinaryTransitions waveValues startCycle shownCycles multiplier
Parameters:
'a array
startCycle : int
shownCycles : int
multiplier : int
Returns: NonBinaryTransition array * 'a array
|
|
Full Usage:
displayBigIntOnWave wsModel width waveValues transitions gapCache
Parameters:
WaveSimModel
width : int
waveValues : bigint array
transitions : NonBinaryTransition array
gapCache : GapStore
Returns: ReactElement list
|
Should be refactored together with
|
Full Usage:
displayUInt32OnWave wsModel width waveValues transitions gapCache
Parameters:
WaveSimModel
width : int
waveValues : uint32 array
transitions : NonBinaryTransition array
gapCache : GapStore
Returns: ReactElement list
|
Should be refactored together with
|
Full Usage:
generateWaveform ws index wave
Parameters:
WaveSimModel
index : WaveIndexT
wave : Wave
Returns: Wave
|
Called when
|
|
|
Full Usage:
getWaves librarySheets ws fs
Parameters:
Set<string>
ws : WaveSimModel
fs : FastSimulation
Returns: Map<WaveIndexT, Wave>
|
Get all simulatable waves from CanvasState. Includes top-level Input and Output ports. Waves contain info which will be used later to create the SVGs for those waves actually selected. Init value of these from this function is None. `librarySheets` names the sheets that came from a component library, whose innards are not offered - see isInsideLibraryComponent.
|
Full Usage:
highZoom clkCycleWidth
Parameters:
float
Returns: bool
|
|
Full Usage:
makeCoords clkCycleWidth clkCycle transition
Parameters:
float
clkCycle : int
transition : Transition
Returns: XYPos * XYPos * XYPos * XYPos
|
|
Full Usage:
makeWaveformsWithTimeOut timeOut ws wavesToBeMade
Parameters:
float option
ws : WaveSimModel
wavesToBeMade : WaveIndexT list
Returns: (type)
An anonymous record with the following information:a) WSM (WaveSimModel with updated waveforms),b) NumberDone (no of waveforms made), and c) TimeTaken (Some timeTaken when greater than timeOut or None
if completed with no time out).
|
This function has been augmented with performance monitoring function, turn
|
Full Usage:
makeXCoords clkCycleWidth clkCycle transition
Parameters:
float
clkCycle : int
transition : Transition
Returns: float * float
|
|
|
|
Full Usage:
nonBinaryWavePoints clkCycleWidth startCycle index transition
Parameters:
float
startCycle : int
index : int
transition : NonBinaryTransition
Returns: XYPos array * XYPos array
|
|
Full Usage:
subSamp arr start count mult
Parameters:
'T array
start : int
count : int
mult : int
Returns: 'T array
|
|
|
|
Full Usage:
xShift clkCycleWidth
Parameters:
float
Returns: float
|