InputPortId Type
Integer id of a component port, unique within its SHEET. Connection ports and connected component ports have the same port Id InputPortId and OutputPortID wrap the id to distinguish component inputs and outputs some times (e.g. in simulation)
Union cases
| Union case | Description |
|
|