PortId Type
The id of a port, undirected: see InputPortId and OutputPortId below for the directed forms the code uses where it knows which side of a connection it is on.
Union cases
| Union case | Description |
Full Usage:
PortId int
Parameters:
int
|
|