ShortcutId Type
Every shortcut identity in Issie. Adding a case here is a compile error until KeyBindings.actionOf binds it, which is the point: there is no way to describe a shortcut and forget to implement it. Several identities share a chord and are told apart only by context - Escape is four different actions.
Union cases
| Union case | Description |
Full Usage:
GsCtrlHoldPorts
|
|
Full Usage:
GsCtrlWheelZoom
|
|
Full Usage:
GsShiftDragPan
|
|
Full Usage:
GsSpaceDragPan
|
|
Full Usage:
GsTabBetweenBoxes
|
|
Full Usage:
ScAbout
|
|
Full Usage:
ScAlign
|
|
Full Usage:
ScAppZoomIn
|
|
Full Usage:
ScAppZoomOut
|
|
Full Usage:
ScAppZoomReset
|
|
Full Usage:
ScBrowserNext
|
|
Full Usage:
ScBrowserOpen
|
|
Full Usage:
ScBrowserParent
|
|
Full Usage:
ScBrowserPrev
|
|
Full Usage:
ScCancelGesture
|
|
Full Usage:
ScClosePopup
|
|
Full Usage:
ScCopy
|
|
Full Usage:
ScDelete
|
|
Full Usage:
ScDeselect
|
|
Full Usage:
ScDevTools
|
|
Full Usage:
ScDistribute
|
|
Full Usage:
ScFlipHorizontal
|
|
Full Usage:
ScFlipVertical
|
|
Full Usage:
ScFullScreen
|
|
Full Usage:
ScLeaveTextBox
|
|
Full Usage:
ScMovePortsHelp
|
|
Full Usage:
ScNewSheet
|
|
Full Usage:
ScPaste
|
|
Full Usage:
ScQuit
|
|
Full Usage:
ScRedo
|
|
Full Usage:
ScRedrawAllWires
|
|
Full Usage:
ScRedrawFloatingWires
|
|
Full Usage:
ScRenameComponent
|
|
Full Usage:
ScRotateAnticlockwise
|
|
Full Usage:
ScRotateClockwise
|
|
Full Usage:
ScRotateLabel
|
|
Full Usage:
ScSaveSheet
|
|
Full Usage:
ScSelectAll
|
|
Full Usage:
ScSuppressScroll
|
|
Full Usage:
ScSwallowCloseWindow
|
|
Full Usage:
ScTextCopy
|
|
Full Usage:
ScTextCut
|
|
Full Usage:
ScTextPaste
|
|
Full Usage:
ScTextRedo
|
|
Full Usage:
ScTextSelectAll
|
|
Full Usage:
ScTextUndo
|
|
Full Usage:
ScThemeDefault
|
|
Full Usage:
ScThemeGrayscale
|
|
Full Usage:
ScThemeLight
|
|
Full Usage:
ScToggleBuildTab
|
|
Full Usage:
ScToggleGrid
|
|
Full Usage:
ScToggleWireArrows
|
|
Full Usage:
ScUndo
|
|
Full Usage:
ScWaveStepBack
|
|
Full Usage:
ScWaveStepForward
|
|
Full Usage:
ScWireTypeJump
|
|
Full Usage:
ScWireTypeModern
|
|
Full Usage:
ScWireTypeRadiussed
|
|
Full Usage:
ScZoomIn
|
|
Full Usage:
ScZoomOut
|
|
Full Usage:
ScZoomToFit
|
Instance members
| Instance member | Description |
Full Usage:
this.IsGsCtrlHoldPorts
Returns: bool
|
|
Full Usage:
this.IsGsCtrlWheelZoom
Returns: bool
|
|
Full Usage:
this.IsGsShiftDragPan
Returns: bool
|
|
Full Usage:
this.IsGsSpaceDragPan
Returns: bool
|
|
Full Usage:
this.IsGsTabBetweenBoxes
Returns: bool
|
|
Full Usage:
this.IsScAbout
Returns: bool
|
|
Full Usage:
this.IsScAlign
Returns: bool
|
|
Full Usage:
this.IsScAppZoomIn
Returns: bool
|
|
Full Usage:
this.IsScAppZoomOut
Returns: bool
|
|
Full Usage:
this.IsScAppZoomReset
Returns: bool
|
|
Full Usage:
this.IsScBrowserNext
Returns: bool
|
|
Full Usage:
this.IsScBrowserOpen
Returns: bool
|
|
Full Usage:
this.IsScBrowserParent
Returns: bool
|
|
Full Usage:
this.IsScBrowserPrev
Returns: bool
|
|
Full Usage:
this.IsScCancelGesture
Returns: bool
|
|
Full Usage:
this.IsScClosePopup
Returns: bool
|
|
Full Usage:
this.IsScCopy
Returns: bool
|
|
Full Usage:
this.IsScDelete
Returns: bool
|
|
Full Usage:
this.IsScDeselect
Returns: bool
|
|
Full Usage:
this.IsScDevTools
Returns: bool
|
|
Full Usage:
this.IsScDistribute
Returns: bool
|
|
Full Usage:
this.IsScFlipHorizontal
Returns: bool
|
|
Full Usage:
this.IsScFlipVertical
Returns: bool
|
|
Full Usage:
this.IsScFullScreen
Returns: bool
|
|
Full Usage:
this.IsScLeaveTextBox
Returns: bool
|
|
Full Usage:
this.IsScMovePortsHelp
Returns: bool
|
|
Full Usage:
this.IsScNewSheet
Returns: bool
|
|
Full Usage:
this.IsScPaste
Returns: bool
|
|
Full Usage:
this.IsScQuit
Returns: bool
|
|
Full Usage:
this.IsScRedo
Returns: bool
|
|
Full Usage:
this.IsScRedrawAllWires
Returns: bool
|
|
Full Usage:
this.IsScRedrawFloatingWires
Returns: bool
|
|
Full Usage:
this.IsScRenameComponent
Returns: bool
|
|
Full Usage:
this.IsScRotateAnticlockwise
Returns: bool
|
|
Full Usage:
this.IsScRotateClockwise
Returns: bool
|
|
Full Usage:
this.IsScRotateLabel
Returns: bool
|
|
Full Usage:
this.IsScSaveSheet
Returns: bool
|
|
Full Usage:
this.IsScSelectAll
Returns: bool
|
|
Full Usage:
this.IsScSuppressScroll
Returns: bool
|
|
Full Usage:
this.IsScSwallowCloseWindow
Returns: bool
|
|
Full Usage:
this.IsScTextCopy
Returns: bool
|
|
Full Usage:
this.IsScTextCut
Returns: bool
|
|
Full Usage:
this.IsScTextPaste
Returns: bool
|
|
Full Usage:
this.IsScTextRedo
Returns: bool
|
|
Full Usage:
this.IsScTextSelectAll
Returns: bool
|
|
Full Usage:
this.IsScTextUndo
Returns: bool
|
|
Full Usage:
this.IsScThemeDefault
Returns: bool
|
|
Full Usage:
this.IsScThemeGrayscale
Returns: bool
|
|
Full Usage:
this.IsScThemeLight
Returns: bool
|
|
Full Usage:
this.IsScToggleBuildTab
Returns: bool
|
|
Full Usage:
this.IsScToggleGrid
Returns: bool
|
|
Full Usage:
this.IsScToggleWireArrows
Returns: bool
|
|
Full Usage:
this.IsScUndo
Returns: bool
|
|
Full Usage:
this.IsScWaveStepBack
Returns: bool
|
|
Full Usage:
this.IsScWaveStepForward
Returns: bool
|
|
Full Usage:
this.IsScWireTypeJump
Returns: bool
|
|
Full Usage:
this.IsScWireTypeModern
Returns: bool
|
|
Full Usage:
this.IsScWireTypeRadiussed
Returns: bool
|
|
Full Usage:
this.IsScZoomIn
Returns: bool
|
|
Full Usage:
this.IsScZoomOut
Returns: bool
|
|
Full Usage:
this.IsScZoomToFit
Returns: bool
|
|