SidecarAnswer Type
What an operation answered. One case per operation, so that an answer cannot be handled as though it were the answer to something else.
Union cases
| Union case | Description |
|
|
Full Usage:
AnsFetched(Result<unit, SidecarFailure>, (FComponentId * (RamKey * RamView)) list, (WaveIndexT * int * bigint) option)
Parameters:
Result<unit, SidecarFailure>
Item2 : (FComponentId * (RamKey * RamView)) list
Item3 : (WaveIndexT * int * bigint) option
|
|
Full Usage:
AnsRan Result<(int * bool), SidecarFailure>
Parameters:
Result<(int * bool), SidecarFailure>
|
|
Full Usage:
AnsStepped
|
|
Full Usage:
AnsSteppedTo(before, startedMs, result)
Parameters:
int
startedMs : float
result : Result<(int * bool), SidecarFailure>
|
|
Instance members
| Instance member | Description |
Full Usage:
this.IsAnsBuilt
Returns: bool
|
|
Full Usage:
this.IsAnsFetched
Returns: bool
|
|
Full Usage:
this.IsAnsRan
Returns: bool
|
|
Full Usage:
this.IsAnsStepped
Returns: bool
|
|
Full Usage:
this.IsAnsSteppedTo
Returns: bool
|
|