BindOffer Type
An offer to bind one unbound instance parameter to a same-named parameter on an ancestor sheet, by materialising parameters and bindings along every instance path from the ancestor down to the instance.
Record fields
| Record Field | Description |
|
|
Full Usage:
BindsTo
Field type: string
|
|
Full Usage:
ChildSheet
Field type: string
|
|
Full Usage:
Declarers
Field type: string list
|
|
Full Usage:
InstanceId
Field type: string
|
|
Full Usage:
InstanceLabel
Field type: string
|
|
Full Usage:
OnSheet
Field type: string
|
|
|