FastData Type
Record fields
| Record Field | Description |
|
|
Full Usage:
Width
Field type: int
|
|
Instance members
| Instance member | Description |
Full Usage:
this.GetBigInt
Returns: bigint
Modifiers: inline |
|
Full Usage:
this.GetQUint32
Returns: uint32
Modifiers: inline |
|
Full Usage:
this.GetUint32
Returns: uint32 option
Modifiers: inline |
Static members
| Static member | Description |
Full Usage:
FastData.MakeFastData(width) (data)
Parameters:
int
data : bigint
Returns: FastData
Modifiers: inline |
if given width <= 32 it will generate Word form FastData, otherwise BigWord. The value is masked into the width, since every stored value must be within its bus width. NB this used to store a positive unmasked (MakeFastData 2 4I gave 4) and to reduce a negative with %, which leaves a negative remainder rather than the two's complement pattern.
|