SimGraph Module
The one way in and out of a SimulationGraph, in ComponentIds.
The key-carrying functions WRAP on the way out, which is free under Fable ([
Functions and values
| Function or value | Description |
Full Usage:
SimGraph.add arg1 comp g
Parameters:
ComponentId
comp : SimulationComponent
g : SimulationGraph
Returns: SimulationGraph
|
|
Full Usage:
SimGraph.containsKey arg1 g
Parameters:
ComponentId
g : SimulationGraph
Returns: bool
|
|
|
|
|
|
Full Usage:
SimGraph.filter f g
Parameters:
ComponentId -> SimulationComponent -> bool
g : SimulationGraph
Returns: SimulationGraph
|
|
Full Usage:
SimGraph.filterValues f g
Parameters:
SimulationComponent -> bool
g : SimulationGraph
Returns: SimulationGraph
|
|
Full Usage:
SimGraph.find arg1 g
Parameters:
ComponentId
g : SimulationGraph
Returns: SimulationComponent
|
|
Full Usage:
SimGraph.fold f state g
Parameters:
'S -> ComponentId -> SimulationComponent -> 'S
state : 'S
g : SimulationGraph
Returns: 'S
|
|
Full Usage:
SimGraph.foldValues f state g
Parameters:
'S -> SimulationComponent -> 'S
state : 'S
g : SimulationGraph
Returns: 'S
|
|
|
|
Full Usage:
SimGraph.iter f g
Parameters:
ComponentId -> SimulationComponent -> unit
g : SimulationGraph
|
|
|
|
Full Usage:
SimGraph.map f g
Parameters:
ComponentId -> SimulationComponent -> SimulationComponent
g : SimulationGraph
Returns: SimulationGraph
|
|
|
|
Full Usage:
SimGraph.ofList pairs
Parameters:
(ComponentId * SimulationComponent) list
Returns: SimulationGraph
|
|
Full Usage:
SimGraph.toList g
Parameters:
SimulationGraph
Returns: (ComponentId * SimulationComponent) list
|
|
Full Usage:
SimGraph.tryFind arg1 g
Parameters:
ComponentId
g : SimulationGraph
Returns: SimulationComponent option
|
|
Full Usage:
SimGraph.values g
Parameters:
SimulationGraph
Returns: ICollection<SimulationComponent>
|
|