BinaryTransition Type
Whether a binary waveform changes at the start of a clock cycle, and what it changes between.
Union cases
| Union case | Description |
Full Usage:
OneToOne
|
|
Full Usage:
OneToZero
|
|
Full Usage:
ZeroToOne
|
|
Full Usage:
ZeroToZero
|
Instance members
| Instance member | Description |
Full Usage:
this.IsOneToOne
Returns: bool
|
|
Full Usage:
this.IsOneToZero
Returns: bool
|
|
Full Usage:
this.IsZeroToOne
Returns: bool
|
|
Full Usage:
this.IsZeroToZero
Returns: bool
|
|